==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebColumnGroupDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { WebColumnDescription } from "./WebColumnDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var WebColumnGroupDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebColumnGroupDescription, _super);
    function WebColumnGroupDescription() {
        var _this = _super.call(this) || this;
        _this.cw = null;
        _this.c0 = null;
        return _this;
    }
    WebColumnGroupDescription.prototype.get_type = function () {
        return "WebColumnGroup";
    };
    Object.defineProperty(WebColumnGroupDescription.prototype, "children", {
        get: function () {
            return this.cw;
        },
        set: function (a) {
            this.cw = a;
            this.e("Children");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebColumnGroupDescription.prototype, "collapsibleIndicatorTemplateRef", {
        get: function () {
            return this.c0;
        },
        set: function (a) {
            this.c0 = a;
            this.e("CollapsibleIndicatorTemplateRef");
        },
        enumerable: false,
        configurable: true
    });
    WebColumnGroupDescription.$t = markType(WebColumnGroupDescription, 'WebColumnGroupDescription', WebColumnDescription.$);
    WebColumnGroupDescription.__canMarshalByValue1 = true;
    WebColumnGroupDescription.__marshalByValueAlias1 = "ColumnGroup";
    return WebColumnGroupDescription;
}(WebColumnDescription));
export { WebColumnGroupDescription };

==> igniteui-react-core-19.0.0.tgz: package/esm5/lib/WebColumnGroupDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { WebColumnDescription } from "./WebColumnDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var WebColumnGroupDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebColumnGroupDescription, _super);
    function WebColumnGroupDescription() {
        var _this = _super.call(this) || this;
        _this.cw = null;
        _this.cz = false;
        _this.c0 = false;
        _this.c4 = null;
        return _this;
    }
    WebColumnGroupDescription.prototype.get_type = function () {
        return "WebColumnGroup";
    };
    Object.defineProperty(WebColumnGroupDescription.prototype, "children", {
        get: function () {
            return this.cw;
        },
        set: function (a) {
            this.cw = a;
            this.g("Children");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebColumnGroupDescription.prototype, "collapsible", {
        get: function () {
            return this.cz;
        },
        set: function (a) {
            this.cz = a;
            this.g("Collapsible");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebColumnGroupDescription.prototype, "expanded", {
        get: function () {
            return this.c0;
        },
        set: function (a) {
            this.c0 = a;
            this.g("Expanded");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebColumnGroupDescription.prototype, "collapsibleIndicatorTemplateRef", {
        get: function () {
            return this.c4;
        },
        set: function (a) {
            this.c4 = a;
            this.g("CollapsibleIndicatorTemplateRef");
        },
        enumerable: false,
        configurable: true
    });
    WebColumnGroupDescription.$t = markType(WebColumnGroupDescription, 'WebColumnGroupDescription', WebColumnDescription.$);
    WebColumnGroupDescription.__canMarshalByValue1 = true;
    WebColumnGroupDescription.__marshalByValueAlias1 = "ColumnGroup";
    return WebColumnGroupDescription;
}(WebColumnDescription));
export { WebColumnGroupDescription };
